@@ -58,6 +58,7 @@ from gvm.protocols.gmpv8.types import (
 
 
 __all__ = [
+    "AggregateStatistic",
     "AlertCondition",
     "AlertEvent",
     "AlertMethod",
@@ -77,9 +78,11 @@ __all__ = [
     "SeverityLevel",
     "SnmpAuthAlgorithm",
     "SnmpPrivacyAlgorithm",
+    "SortOrder",
     "TicketStatus",
     "TimeUnit",
     "UserAuthType",
+    "get_aggregate_statistic_from_string",
     "get_alert_condition_from_string",
     "get_alert_event_from_string",
     "get_alert_method_from_string",
@@ -97,6 +100,7 @@ __all__ = [
     "get_report_format_id_from_string",
     "get_scanner_type_from_string",
     "get_severity_level_from_string",
+    "get_sort_order_from_string",
     "get_snmp_auth_algorithm_from_string",
     "get_snmp_privacy_algorithm_from_string",
     "get_ticket_status_from_string",
@@ -105,12 +109,50 @@ __all__ = [
 ]
 
 
+class AggregateStatistic(Enum):
+    """Enum for aggregate statistic types"""
+
+    COUNT = "count"  # Number of items
+    C_COUNT = "c_count"  # Cumulative number of items
+    C_SUM = "c_sum"  # Cumulative sum of values
+    MAX = "max"  # Maximum value
+    MEAN = "mean"  # Arithmetic mean of values
+    MIN = "min"  # Minimum value
+    SUM = "sum"  # Sum of values
+    TEXT = "text"  # Text column value
+    VALUE = "value"  # Group or subgroup column value
+
+
+def get_aggregate_statistic_from_string(
+    aggregate_statistic: Optional[str],
+) -> Optional[AggregateStatistic]:
+    """
+    Convert a aggregate statistic string to an actual AggregateStatistic
+    instance.
+
+    Arguments:
+        aggregate_statistic: Aggregate statistic string to convert to a
+            AggregateStatistic
+    """
+    if not aggregate_statistic:
+        return None
+
+    try:
+        return AggregateStatistic[aggregate_statistic.upper()]
+    except KeyError:
+        raise InvalidArgument(
+            argument='aggregate_statistic',
+            function=get_aggregate_statistic_from_string.__name__,
+        ) from None
+
+
 class EntityType(Enum):
     """Enum for entity types """
 
     AGENT = "agent"
     ALERT = "alert"
     ASSET = "asset"
+    AUDIT = "audit"
     CERT_BUND_ADV = "cert_bund_adv"
     CPE = "cpe"
     CREDENTIAL = "credential"
@@ -126,6 +168,7 @@ class EntityType(Enum):
     OVALDEF = "ovaldef"
     OVERRIDE = "override"
     PERMISSION = "permission"
+    POLICY = "policy"
     PORT_LIST = "port_list"
     REPORT = "report"
     REPORT_FORMAT = "report_format"
@@ -439,6 +482,34 @@ def get_scanner_type_from_string(
     )
 
 
+class SortOrder(Enum):
+    """Enum for sort order"""
+
+    ASCENDING = "ascending"
+    DESCENDING = "descending"
+
+
+def get_sort_order_from_string(
+    sort_order: Optional[str],
+) -> Optional[SortOrder]:
+    """
+    Convert a sort order string to an actual SortOrder instance.
+
+    Arguments:
+        sort_order: Sort order string to convert to a SortOrder
+    """
+    if not sort_order:
+        return None
+
+    try:
+        return SortOrder[sort_order.upper()]
+    except KeyError:
+        raise InvalidArgument(
+            argument='sort_order',
+            function=get_sort_order_from_string.__name__,
+        ) from None
+
+
 class _UsageType(Enum):
     """Enum for usage types """
 
